contained

Function contained 

pub fn contained(
    tree: &mut Tree,
    limits: &Limits,
    width: impl Into<Length>,
    height: impl Into<Length>,
    f: impl FnOnce(&mut Tree, &Limits) -> Size,
)
Available on crate feature advanced only.
Computes the resulting Size that fits the Limits given some width and height requirements and a closure that produces the content inside the given Limits.