padded

Function padded 

pub fn padded(
    tree: &mut Tree,
    limits: &Limits,
    width: impl Into<Length>,
    height: impl Into<Length>,
    padding: impl Into<Padding>,
    layout: impl FnOnce(&mut Tree, &Limits) -> Size,
)
Available on crate feature advanced only.
Computes the Size that fits the Limits given some width, height, and Padding requirements and a closure that produces the content inside the given Limits.