Limits

Struct Limits 

pub struct Limits {
    pub min: Size,
    pub max: Size,
    pub compression: Size<bool>,
    pub infinite: Size<bool>,
}
Available on crate feature advanced only.
A set of size constraints for layouting.

Fields

min: Size

The minimum bounds.

max: Size

The maximum bounds.

compression: Size<bool>

Whether fluid lengths should be compressed to intrinsic dimensions.

infinite: Size<bool>

Whether intrinsic dimensions can exceed maximum bounds. The maximum boundary becomes a hint in this case.

Implementations



impl Limits

pub const fn new(min: Size, max: Size) -> Limits

Creates new Limits with the given minimum and maximum Size.

pub const fn with_flags( min: Size, max: Size, compression: Size<bool>, infinite: Size<bool>, ) -> Limits

Creates new Limits with the given minimum and maximum Size, whether fluid lengths should be compressed to intrinsic dimensions, and whether the upper bounds may grow indefinitely.

pub fn bounds(&self) -> Size

Returns the maximum Size of the Limits.

On axes with infinite bounds, the value is f32::INFINITY, as the maximum boundary becomes a hint in this case.

pub fn width(self, width: impl Into<Length>) -> Limits

Applies a width constraint to the current Limits.

pub fn height(self, height: impl Into<Length>) -> Limits

Applies a height constraint to the current Limits.

pub fn shrink(&self, size: impl Into<Size>) -> Limits

Shrinks the current Limits by the given Size.

pub fn loose(&self) -> Limits

Removes the minimum Size constraint for the current Limits.

pub fn resolve( &self, width: impl Into<Length>, height: impl Into<Length>, intrinsic_size: Size, ) -> Size

Computes the resulting Size that fits the Limits given some width and height requirements and the intrinsic size of some content.

pub fn resolve_width( &self, width: impl Into<Length>, intrinsic_width: f32, ) -> f32

Resolves only the width of the Limits.

pub fn resolve_height( &self, height: impl Into<Length>, intrinsic_height: f32, ) -> f32

Resolves only the height of the Limits.