Function next_to_each_other
pub fn next_to_each_other(
tree: &mut Tree,
left: Size,
right: Size,
spacing: f32,
)Available on crate feature
advanced only.Expand description
Lays out two children side by side in the provided widget::Tree.
The tree must have exactly two children. The first is placed at the left
edge, and the second to its right after spacing, both vertically
centered with respect to each other.
The resulting size is stored in the tree, along with the children’s sizes and translations.